import { openBlock, createElementBlock, normalizeStyle, renderSlot, normalizeClass } from 'vue';

var script$2 = {
  name: 'Row',
  props: {
    gutter: Number,
    columns: {
      type: Number,
      "default": 12
    }
  },
  data: function data() {
    return {
      styleGeneral: this.createGutter(this.gutter)
    };
  },
  methods: {
    createGutter: function createGutter(gutter) {
      return gutter ? "--paddingVGR:".concat(gutter / 2, "px;--marginVGR:-").concat(gutter / 2, "px") : '--paddingVGR:0px;--marginVGR:0px';
    }
  }
};

function render$2(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", {
    style: normalizeStyle($data.styleGeneral),
    "class": "grid-row"
  }, [renderSlot(_ctx.$slots, "default")], 4
  /* STYLE */
  );
}

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z$2 = "\n.grid-row[data-v-4424dc71] {\n  box-sizing: border-box;\n  display: flex;\n  flex-wrap: wrap;\n  width: calc(100% + (var(--paddingVGR) * 2));\n  margin: var(--marginVGR);\n}\n";
styleInject(css_248z$2);

script$2.render = render$2;
script$2.__scopeId = "data-v-4424dc71";
script$2.__file = "src/Row.vue";

var script$1 = {
  name: 'Col',
  props: {
    xs: Number,
    sm: Number,
    md: Number,
    lg: Number,
    xl: Number,
    xsOffset: {
      required: false,
      type: Number
    },
    smOffset: {
      required: false,
      type: Number
    },
    mdOffset: {
      required: false,
      type: Number
    },
    lgOffset: {
      required: false,
      type: Number
    },
    xlOffset: {
      required: false,
      type: Number
    },
    order: {
      required: false,
      type: Number
    }
  },
  data: function data() {
    var styleGeneral = this.createStyleSize();

    if (this.xs || this.sm || this.md || this.lg || this.xl) {
      styleGeneral += "--colFlexVGR:0;";
    } else {
      styleGeneral = "--colFlexVGR:1;";
    }

    if (this.order || this.order === 0) {
      styleGeneral += "--orderSGR:".concat(this.order, ";");
    }

    return {
      classGeneral: "colVGR ".concat(this.createClassSize()),
      styleGeneral: styleGeneral
    };
  },
  methods: {
    getValue: function getValue(breakpoint) {
      var localColumns = this.$parent.columns;

      if (breakpoint > localColumns) {
        breakpoint = localColumns;
      }

      return breakpoint ? "".concat(breakpoint / localColumns * 100, "%") : false;
    },
    createClassSize: function createClassSize() {
      var newClass = 'grid-column colVGR-xs ';
      newClass += this.sm ? 'colVGR-sm ' : '';
      newClass += this.md ? 'colVGR-md ' : '';
      newClass += this.lg ? 'colVGR-lg ' : '';
      newClass += this.xl ? 'colVGR-xl ' : '';
      newClass += this.xsOffset ? 'colVGR-Offset-xs ' : '';
      newClass += this.smOffset ? 'colVGR-Offset-sm ' : '';
      newClass += this.mdOffset ? 'colVGR-Offset-md ' : '';
      newClass += this.lgOffset ? 'colVGR-Offset-lg ' : '';
      newClass += this.xlOffset ? 'colVGR-Offset-xl ' : '';
      return newClass;
    },
    createStyleSize: function createStyleSize() {
      var newStyle = ''; // Scale

      newStyle += this.xs ? "--xsWidthVGR:".concat(this.getValue(this.xs), "; ") : "--xsWidthVGR:100%; ";
      newStyle += this.sm ? "--smWidthVGR:".concat(this.getValue(this.sm), "; ") : '';
      newStyle += this.md ? "--mdWidthVGR:".concat(this.getValue(this.md), "; ") : '';
      newStyle += this.lg ? "--lgWidthVGR:".concat(this.getValue(this.lg), "; ") : '';
      newStyle += this.xl ? "--xlWidthVGR:".concat(this.getValue(this.xl), "; ") : ''; // Offset

      newStyle += this.xsOffset ? "--xsOffset:".concat(this.getValue(this.xsOffset), "; ") : "";
      newStyle += this.smOffset ? "--smOffset:".concat(this.getValue(this.smOffset), "; ") : '';
      newStyle += this.mdOffset ? "--mdOffset:".concat(this.getValue(this.mdOffset), "; ") : '';
      newStyle += this.lgOffset ? "--lgOffset:".concat(this.getValue(this.lgOffset), "; ") : '';
      newStyle += this.xlOffset ? "--xlOffset:".concat(this.getValue(this.xlOffset), "; ") : '';
      return newStyle;
    }
  }
};

function render$1(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", {
    style: normalizeStyle($data.styleGeneral),
    "class": normalizeClass($data.classGeneral)
  }, [renderSlot(_ctx.$slots, "default")], 6
  /* CLASS, STYLE */
  );
}

var css_248z$1 = "\n.colVGR[data-v-5ac92ce2] {\n  position: relative;\n  box-sizing: border-box;\n  flex-grow: var(--colFlexVGR);\n  padding: var(--paddingVGR);\n  order: var(--orderSGR);\n}\n.colVGR-xs[data-v-5ac92ce2] {\n  flex-basis: var(--xsWidthVGR);\n  max-width: var(--xsWidthVGR);\n}\n.colVGR-Offset-xs[data-v-5ac92ce2] {\n  margin-left: var(--xsOffset);\n}\n@media (min-width: 576px) {\n.colVGR-sm[data-v-5ac92ce2] {\n    flex-basis: var(--smWidthVGR);\n    max-width: var(--smWidthVGR);\n}\n.colVGR-Offset-sm[data-v-5ac92ce2] {\n    margin-left: var(--smOffset);\n}\n}\n@media (min-width: 768px) {\n.colVGR-md[data-v-5ac92ce2] {\n    flex-basis: var(--mdWidthVGR);\n    max-width: var(--mdWidthVGR);\n}\n.colVGR-Offset-md[data-v-5ac92ce2] {\n    margin-left: var(--mdOffset);\n}\n}\n@media (min-width: 992px) {\n.colVGR-lg[data-v-5ac92ce2] {\n    flex-basis: var(--lgWidthVGR);\n    max-width: var(--lgWidthVGR);\n}\n.colVGR-Offset-lg[data-v-5ac92ce2] {\n    margin-left: var(--lgOffset);\n}\n}\n@media (min-width: 1200px) {\n.colVGR-xl[data-v-5ac92ce2] {\n    flex-basis: var(--xlWidthVGR);\n    max-width: var(--xlWidthVGR);\n}\n.colVGR-Offset-xl[data-v-5ac92ce2] {\n    margin-left: var(--xlOffset);\n}\n}\n";
styleInject(css_248z$1);

script$1.render = render$1;
script$1.__scopeId = "data-v-5ac92ce2";
script$1.__file = "src/Column.vue";

var script = {
  name: 'Hidden',
  data: function data() {
    return {
      classGeneral: "".concat(this.createClassSize())
    };
  },
  props: {
    xs: Boolean,
    sm: Boolean,
    md: Boolean,
    lg: Boolean,
    xl: Boolean
  },
  methods: {
    createClassSize: function createClassSize() {
      var newClass = '';
      newClass += this.xs ? 'hiddenVGR-xs ' : '';
      newClass += this.sm ? 'hiddenVGR-sm ' : '';
      newClass += this.md ? 'hiddenVGR-md ' : '';
      newClass += this.lg ? 'hiddenVGR-lg ' : '';
      newClass += this.xl ? 'hiddenVGR-xl ' : '';
      return newClass;
    }
  }
};

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return openBlock(), createElementBlock("div", {
    "class": normalizeClass($data.classGeneral)
  }, [renderSlot(_ctx.$slots, "default")], 2
  /* CLASS */
  );
}

var css_248z = "\n@media (max-width: 575px) {\n.hiddenVGR-xs[data-v-4e75e9e3] {\n    display: none;\n}\n}\n@media (min-width: 576px) and (max-width: 767px) {\n.hiddenVGR-sm[data-v-4e75e9e3] {\n    display: none;\n}\n}\n@media (min-width: 768px) and (max-width: 991px) {\n.hiddenVGR-md[data-v-4e75e9e3] {\n    display: none;\n}\n}\n@media (min-width: 992px) and (max-width: 1199px) {\n.hiddenVGR-lg[data-v-4e75e9e3] {\n    display: none;\n}\n}\n@media (min-width: 1200px) {\n.hiddenVGR-xl[data-v-4e75e9e3] {\n    display: none;\n}\n}\n";
styleInject(css_248z);

script.render = render;
script.__scopeId = "data-v-4e75e9e3";
script.__file = "src/Hidden.vue";

export { script$1 as Column, script as Hidden, script$2 as Row };
//# sourceMappingURL=vue-grid-responsive.esm.js.map
